@@ -3,5 +3,6 @@ __all__ = [
         'analytics',
         'misc',
         'transform',
-        'graphics'
+        'graphics',
+        'dataclean',
         ]
\ No newline at end of file
