@@ -1,32 +1,11 @@
 import pandas as pd
 from sklearn.metrics import confusion_matrix
 import numpy as np
-import seaborn as sns
 import matplotlib.pyplot as plt
 from yellowbrick.classifier import discrimination_threshold
 from sklearn.metrics import PrecisionRecallDisplay
 
-def fis_machine_date_lags(df, num_lags = 7):
-    """
-    Crea nuevas columnas en un DataFrame con los lags num_lags definidos (7 default)
-    """
-    #Crea el objeto data frame
-    lags = pd.Dataframe()
-    #Crear todos los lags
-    for cada in range(1, num_lags):
-        lags['lag_'+str(cada)] = df.shift(cada).iloc[:0]
-    return(lags)
-
-def fis_machine_date_rolling_mean(df, num_periodos = 7):
-    """
-    Crea num_periodos nuevas columnas en un DataFrame con la media movil de 1 a num_periodos
-    """
-    mm = pd.DataFrame()
-    for cada in range (1, num_periodos):
-        mm['rm_'+str(cada)] = df.shift(1).rolling(cada).mean().iloc[:,0]
-    return(mm)
-
-def fis_machine_metric_compute(real, scoring, umbral=0.5,graf_recall=False,graf_umbral=False,model=None,x=None,y=None):
+def fis_metric_compute(real, scoring, umbral=0.5,graf_recall=False,graf_umbral=False,model=None,x=None,y=None):
     """
     umbral --> threshold de % de probabilidad a partir de la cual es True (1)  
     
@@ -75,7 +54,7 @@ def fis_machine_metric_compute(real, scoring, umbral=0.5,graf_recall=False,graf_
         plt.show()
     print('\n====================================================================')
     
-def fis_machine_metric_max_roi(real,scoring, salida = 'grafico',itn=0,ifp=-15,ifn=-85,itp=85):
+def fis_metric_max_roi(real,scoring, salida = 'grafico',itn=0,ifp=-15,ifn=-85,itp=85):
     """
     salida <> "grafico" devuelve valor numérico max ROI, para automatizaciones
     #DEFINIMOS LA MATRIZ DE IMPACTO
